@@ -4,17 +4,14 @@ require 5.005_62;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = '0.30';
+require Exporter;
+our %EXPORT_TAGS = ( 'all' => [ qw() ] );
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+our $VERSION = '0.31';
+our @ISA = qw(Exporter);
 
-# The following are for debugging only
-#use ExtUtils::Embed;
-#use Inline C => Config => CCFLAGS => "-g"; # add debug stubs to C lib
-#use Inline Config => CLEAN_AFTER_BUILD => 0; # cp _Inline/build/Text/Scan/Scan.xs .
-
-use Inline C => 'DATA',
-            VERSION => '0.30',
-            NAME => 'Text::Scan' ;
+require XSLoader;
+XSLoader::load('Text::Scan', $VERSION);
 
 sub serialize {
     my ($self, $filename) = @_;
@@ -167,6 +164,8 @@ About unicode/utf8 strings. Text::Scan acts at the octet level so it's not aware
 
 =head1 NEW
 
+In v 0.31: Removed Inline::C dependency
+
 In v 0.30: "inclboundary" character class. Empty by default.
 
 In v 0.19: "boundary" character class defines legal boundary characters for all matches. Default is single space for backward compatibility.
